@@ -3,6 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'gcc-ar',
@@ -11,8 +13,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/python-inst/bin',
- 'BINLIBDEST': '/python-inst/lib/python3.9',
- 'BLDLIBRARY': '-L. -lpython3.9',
+ 'BINLIBDEST': '/python-inst/lib/python3.10',
+ 'BLDLIBRARY': '-L. -lpython3.10',
  'BLDSHARED': '/usr/bin/ccache gcc '
               '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
               '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
@@ -65,19 +67,19 @@ build_time_vars = {'ABIFLAGS': '',
                 "'PKG_CONFIG=/usr/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=/opt/rh/gcc-toolset-12/root/usr/lib64/pkgconfig:/opt/rh/gcc-toolset-12/root/usr/lib64/pkgconfig'",
  'CONFINCLUDEDIR': '/python-inst/include',
- 'CONFINCLUDEPY': '/python-inst/include/python3.9',
+ 'CONFINCLUDEPY': '/python-inst/include/python3.10',
  'COREPYTHONPATH': '',
  'COVERAGE_INFO': '/home/buildslave/build/workdir/UnpackedTarball/python3/coverage.info',
  'COVERAGE_REPORT': '/home/buildslave/build/workdir/UnpackedTarball/python3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
- 'CXX': '/usr/bin/ccache g++ -pthread',
- 'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.9 '
-             '/python-inst/lib/python3.9/lib-dynload',
- 'DESTLIB': '/python-inst/lib/python3.9',
+ 'CXX': '/usr/bin/ccache g++  -pthread',
+ 'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.10 '
+             '/python-inst/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/python-inst/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/python-inst/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/python-inst/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -99,11 +101,12 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-3.9.so',
+ 'EXT_SUFFIX': '.cpython-3.10.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
@@ -141,6 +144,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -193,6 +197,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -430,6 +435,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -438,7 +444,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -466,6 +471,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -526,6 +532,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -537,30 +544,29 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'INCLDIRSTOMAKE': '/python-inst/include /python-inst/include '
-                   '/python-inst/include/python3.9 '
-                   '/python-inst/include/python3.9',
+                   '/python-inst/include/python3.10 '
+                   '/python-inst/include/python3.10',
  'INCLUDEDIR': '/python-inst/include',
- 'INCLUDEPY': '/python-inst/include/python3.9',
+ 'INCLUDEPY': '/python-inst/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.9.so.1.0',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': '/usr/bin/ccache g++ -pthread -shared',
+ 'LDCXXSHARED': '/usr/bin/ccache g++  -pthread -shared',
  'LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
             '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
             '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
             '-flto=jobserver -fuse-linker-plugin -O2',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.9.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': '/usr/bin/ccache gcc '
              '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
@@ -570,22 +576,23 @@ build_time_vars = {'ABIFLAGS': '',
              '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
              '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
              '-flto=jobserver -fuse-linker-plugin -O2',
- 'LDVERSION': '3.9',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/python-inst/lib/python3.9',
+ 'LIBDEST': '/python-inst/lib/python3.10',
  'LIBDIR': '/python-inst/lib',
  'LIBFFI_INCLUDEDIR': '/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/python-inst/lib/pkgconfig',
- 'LIBPL': '/python-inst/lib/python3.9/config-3.9-x86_64-linux-gnu',
+ 'LIBPL': '/python-inst/lib/python3.10/config-3.10-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': '/usr/bin/ccache gcc '
            '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
            '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
@@ -600,7 +607,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/python-inst/lib/python3.9',
+ 'MACHDESTLIB': '/python-inst/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': '/usr/bin/ccache gcc '
            '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
@@ -614,7 +621,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
+                   '_tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -627,8 +634,8 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-linux-gnu\\"',
@@ -638,6 +645,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include',
  'OPENSSL_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g  -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -647,8 +655,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
-                'Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
@@ -656,7 +663,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -669,6 +676,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
@@ -695,6 +703,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
                     '-flto=jobserver -fuse-linker-plugin -O2',
  'PY_CPPFLAGS': '-I. -I./Include',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
                '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
@@ -744,9 +753,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-3.9',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-3.10',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -763,21 +773,26 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib '
                './python ./Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.9',
+ 'VERSION': '3.10',
+ 'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
